@@ -19,7 +19,7 @@ class User:
 class UserService:
     def __init__(self, config: Config, request_wrapper: Optional[GqlWrapper] = None):
         self._config = config
-        self._request_wrapper = request_wrapper or GqlWrapper(mcd_id=config.mcd_id, mcd_token=config.mcd_token)
+        self._request_wrapper = request_wrapper or GqlWrapper(config)
 
         self._user = self._request_wrapper.make_request(GET_USER_QUERY)  # get user info
 
