@@ -421,11 +421,19 @@ def add_redshift(ctx, database, name, **kwargs):
 
 @integrations.command(help=f'Setup a Snowflake integration. {WAREHOUSE_VERBIAGE}.')
 @click.pass_obj
-@click.option('--user', help='User with access to snowflake.', required=True)
+@click.option('--user', help='User with access to snowflake.', required=True, cls=AdvancedOptions,
+              at_least_one_set=['password', 'private_key'])
 @click.option('--account', help='Snowflake account name.', required=True)
 @click.option('--warehouse', help='Name of the warehouse for the user.', required=True)
-@click.option('--password', help=f'User\'s password. {PASSWORD_VERBIAGE}.', required=True,
-              cls=AdvancedOptions, prompt_if_requested=True)
+@click.option('--password', help=f'User\'s password if using user/password basic auth. {PASSWORD_VERBIAGE}.',
+              required=False, cls=AdvancedOptions, prompt_if_requested=True,
+              mutually_exclusive_options=['private_key'])
+@click.option('--private-key', help='User\'s private key file path if using key pair auth.',
+              type=click.Path(exists=True), required=False, cls=AdvancedOptions,
+              mutually_exclusive_options=['password'])
+@click.option('--private-key-passphrase', help=f'User\'s private key passphrase if using key pair auth. This argument is only needed when the private key is encrypted. {PASSWORD_VERBIAGE}.',
+              required=False, cls=AdvancedOptions, prompt_if_requested=True,
+              mutually_exclusive_options=['password'], required_with_options=['private_key'])
 @add_common_options(WAREHOUSE_CREATE_OPTIONS)
 @add_common_options(ONBOARDING_CONFIGURATION_OPTIONS)
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
@@ -783,3 +791,30 @@ def delete_key(ctx, **kwargs):
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
 def list_keys(ctx):
     IntegrationKeyService(config=ctx['config']).get_all()
+
+@integrations.command(help='Set the name of a Warehouse.')
+@click.pass_obj
+@click.option('--current-name', required=True, help='Current Name of the Warehouse')
+@click.option('--new-name', required=True, help='Name to give the Warehouse')
+def set_warehouse_name(ctx, **kwargs):
+    ConnectionOperationsService(config=ctx['config']).set_warehouse_name(**kwargs)
+
+
+@integrations.command(help='Update Databricks Notebook to the latest version.')
+@click.pass_obj
+@add_common_options(CONNECTION_OPTIONS)
+def update_databricks_notebook(ctx, **kwargs):
+    DatabricksOnboardingService(config=ctx['config']).update_databricks_notebook(**kwargs)
+
+
+@integrations.command(help='Get the Databricks job info for your connection.')
+@click.pass_obj
+@add_common_options(CONNECTION_OPTIONS)
+def show_databricks_metadata_job_info(ctx, **kwargs):
+    DatabricksOnboardingService(config=ctx['config']).get_databricks_job_info(**kwargs)
+
+
+@integrations.command(help='Get the most up to date databricks notebook version.')
+@click.pass_obj
+def show_current_notebook_version(ctx):
+    DatabricksOnboardingService(config=ctx['config']).get_current_databricks_notebook_version()
