@@ -24,8 +24,9 @@ class EventsOnboardingService(BaseOnboardingService):
         if mapping_file:
             kwargs['mapping'] = read_as_json_string(mapping_file)
 
-        if 'connection_type' in kwargs:
-            kwargs['connection_type'] = kwargs['connection_type'].lower()
+        connection_type = kwargs.get('connection_type')
+        if connection_type:
+            kwargs['connection_type'] = connection_type.lower()
 
         response = self._request_wrapper.make_request_v2(
             query=TOGGLE_EVENT_MUTATION,
