@@ -114,8 +114,8 @@ mutation testDatabricksCredentials($databricksWorkspaceUrl:String!, $databricksW
 """
 
 TEST_SNOWFLAKE_CRED_MUTATION = """
-mutation testSnowflakeCredentials($account:String, $password:String, $user:String, $warehouse:String, $connectionOptions:ConnectionTestOptions) {
-  testSnowflakeCredentials(account:$account, password:$password, user:$user, warehouse:$warehouse, connectionOptions:$connectionOptions) {
+mutation testSnowflakeCredentials($account:String!, $password:String, $privateKey: String, $privateKeyPassphrase: String, $user:String!, $warehouse:String, $connectionOptions:ConnectionTestOptions) {
+  testSnowflakeCredentials(account:$account, password:$password, privateKey:$privateKey, privateKeyPassphrase:$privateKeyPassphrase, user:$user, warehouse:$warehouse, connectionOptions:$connectionOptions) {
     key
   }
 }
@@ -305,3 +305,18 @@ class EventOnboardingDataQueries:
         """,
         operation='deleteEventOnboardingData'
     )
+
+class ConnectionOperationsQueries:
+  set_warehouse_name = GQL(
+      query="""
+        mutation setWarehouseName($dwId:UUID!, $name:String!) {
+            setWarehouseName(dwId:$dwId, name:$name) {
+            warehouse {
+                    name
+                    uuid
+                }
+            }
+        }
+        """,
+        operation='setWarehouseName'
+    )
